==> pentobi_17.3.orig.tar.xz: pentobi-17.3/pentobi_thumbnailer/i18n/de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>main</name>
    <message>
        <source>thumbnailer for Blokus game records as used by Pentobi</source>
        <translation>Vorschaubildgenerator für Blokus-Spieldateien, wie vom Programm Pentobi verwendet</translation>
    </message>
    <message>
        <source>Generate image with height and width &lt;size&gt;.</source>
        <extracomment>Description for command line option --size</extracomment>
        <translation>Bilder mit Höhe und Breite &lt;Größe&gt; generieren.</translation>
    </message>
    <message>
        <source>size</source>
        <extracomment>Value name for command line option --size</extracomment>
        <translation>Größe</translation>
    </message>
    <message>
        <source>input.blksgf</source>
        <extracomment>Name of input file command line argument.</extracomment>
        <translation>Eingabe.blksgf</translation>
    </message>
    <message>
        <source>Blokus SGF input file.</source>
        <translation>Blokus-SGF-Eingabedatei.</translation>
    </message>
    <message>
        <source>output.png</source>
        <extracomment>Name of output image file command line argument.</extracomment>
        <translation>Ausgabe.png</translation>
    </message>
    <message>
        <source>PNG image output file.</source>
        <translation>PNG-Bild-Ausgabedatei.</translation>
    </message>
    <message>
        <source>Invalid image size</source>
        <translation>Ungültige Bildgröße</translation>
    </message>
    <message>
        <source>Too many arguments</source>
        <translation>Zu viele Argumente</translation>
    </message>
    <message>
        <source>Need input and output file argument</source>
        <translation>Benötige Eingabe- und Ausgabedateiargument</translation>
    </message>
    <message>
        <source>Thumbnail creation failed</source>
        <translation>Vorschaubildgenerierung fehlgeschlagen</translation>
    </message>
</context>
</TS>

==> pentobi_18.3.orig.tar.xz: pentobi-18.3/pentobi_thumbnailer/i18n/de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>main</name>
    <message>
        <source>thumbnailer for Blokus game records as used by Pentobi</source>
        <translation>Vorschaubildgenerator für Blokus-Spieldateien, wie vom Programm Pentobi verwendet</translation>
    </message>
    <message>
        <source>Generate image with height and width &lt;size&gt;.</source>
        <extracomment>Description for command line option --size</extracomment>
        <translation>Bilder mit Höhe und Breite &lt;Größe&gt; generieren.</translation>
    </message>
    <message>
        <source>size</source>
        <extracomment>Value name for command line option --size</extracomment>
        <translation>Größe</translation>
    </message>
    <message>
        <source>input.blksgf</source>
        <extracomment>Name of input file command line argument.</extracomment>
        <translation>Eingabe.blksgf</translation>
    </message>
    <message>
        <source>Blokus SGF input file.</source>
        <translation>Blokus-SGF-Eingabedatei.</translation>
    </message>
    <message>
        <source>output.png</source>
        <extracomment>Name of output image file command line argument.</extracomment>
        <translation>Ausgabe.png</translation>
    </message>
    <message>
        <source>PNG image output file.</source>
        <translation>PNG-Bild-Ausgabedatei.</translation>
    </message>
    <message>
        <source>Invalid image size</source>
        <translation>Ungültige Bildgröße</translation>
    </message>
    <message>
        <source>Too many arguments</source>
        <translation>Zu viele Argumente</translation>
    </message>
    <message>
        <source>Need input and output file argument</source>
        <translation>Benötige Eingabe- und Ausgabedateiargument</translation>
    </message>
    <message>
        <source>Thumbnail creation failed</source>
        <translation>Vorschaubildgenerierung fehlgeschlagen</translation>
    </message>
</context>
</TS>
